.. _api_geometry_square:

.. currentmodule:: microstructpy.geometry

microstructpy.geometry.Square
=============================

.. autoclass:: Square
    :members:
    :undoc-members:
    :inherited-members:
